@@ -1,4 +1,4 @@
-//@line 40 "/builds/tinderbox/Fx-Trunk/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/base/content/pageinfo/security.js"
+//@line 40 "/builds/slave/mozilla-1.9.1-linux-nightly/build/browser/base/content/pageinfo/security.js"
 
 var security = {
   // Display the server certificate (static)
@@ -148,9 +148,6 @@ var security = {
 };
 
 function securityOnLoad() {
-  var bundle = srGetStrBundle("chrome://pippki/locale/pippki.properties");
-  var pageInfoBundle = document.getElementById("pageinfobundle");
-
   var info = security._getSecurityInfo();
   if (!info) {
     document.getElementById("securityTab").hidden = true;
@@ -162,6 +159,8 @@ function securityOnLoad() {
     document.getElementById("securityBox").collapsed = false;
   }
 
+  const pageInfoBundle = document.getElementById("pageinfobundle");
+
   /* Set Identity section text */
   setText("security-identity-domain-value", info.hostName);
   
@@ -182,7 +181,7 @@ function securityOnLoad() {
       // way to tell those apart, and no policy way to establish which organization
       // vetting standards are good enough (that's what EV is for) so we default to
       // treating these certs as domain-validated only.
-      owner = pageInfoBundle.getString("securityNoIdentity");
+      owner = pageInfoBundle.getString("securityNoOwner");
       verifier = security.mapIssuerOrganization(info.cAName ||
                                                 info.cert.issuerCommonName ||
                                                 info.cert.issuerName);
@@ -191,7 +190,7 @@ function securityOnLoad() {
   }
   else {
     // We don't have valid identity credentials.
-    owner = pageInfoBundle.getString("securityNoIdentity");
+    owner = pageInfoBundle.getString("securityNoOwner");
     verifier = pageInfoBundle.getString("notset");
     generalPageIdentityString = owner;
   }
@@ -203,8 +202,6 @@ function securityOnLoad() {
   /* Manage the View Cert button*/
   var viewCert = document.getElementById("security-view-cert");
   if (info.cert) {
-    var viewText = pageInfoBundle.getString("securityCertText");
-    setText("security-view-text", viewText);
     security._cert = info.cert;
     viewCert.collapsed = false;
   }
@@ -235,35 +232,36 @@ function securityOnLoad() {
   }
 
   /* Set the Technical Detail section messages */
+  const pkiBundle = document.getElementById("pkiBundle");
   var hdr;
   var msg1;
   var msg2;
 
   if (info.isBroken) {
-    hdr = bundle.GetStringFromName("pageInfo_MixedContent");
-    msg1 = bundle.GetStringFromName("pageInfo_Privacy_Mixed1");
-    msg2 = bundle.GetStringFromName("pageInfo_Privacy_None2");
+    hdr = pkiBundle.getString("pageInfo_MixedContent");
+    msg1 = pkiBundle.getString("pageInfo_Privacy_Mixed1");
+    msg2 = pkiBundle.getString("pageInfo_Privacy_None2");
   }
   else if (info.encryptionStrength >= 90) {
-    hdr = bundle.formatStringFromName("pageInfo_StrongEncryption",
-                          [ info.encryptionAlgorithm, info.encryptionStrength + "" ], 2);
-    msg1 = bundle.GetStringFromName("pageInfo_Privacy_Strong1");
-    msg2 = bundle.GetStringFromName("pageInfo_Privacy_Strong2");
+    hdr = pkiBundle.getFormattedString("pageInfo_StrongEncryption",
+                                       [info.encryptionAlgorithm, info.encryptionStrength + ""]);
+    msg1 = pkiBundle.getString("pageInfo_Privacy_Strong1");
+    msg2 = pkiBundle.getString("pageInfo_Privacy_Strong2");
     security._cert = info.cert;
   }
   else if (info.encryptionStrength > 0) {
-    hdr  = bundle.formatStringFromName("pageInfo_WeakEncryption",
-                          [ info.encryptionAlgorithm, info.encryptionStrength + "" ], 2);
-    msg1 = bundle.formatStringFromName("pageInfo_Privacy_Weak1", [ info.hostName ], 1);
-    msg2 = bundle.GetStringFromName("pageInfo_Privacy_Weak2");
+    hdr  = pkiBundle.getFormattedString("pageInfo_WeakEncryption",
+                                        [info.encryptionAlgorithm, info.encryptionStrength + ""]);
+    msg1 = pkiBundle.getFormattedString("pageInfo_Privacy_Weak1", [info.hostName]);
+    msg2 = pkiBundle.getString("pageInfo_Privacy_Weak2");
   }
   else {
-    hdr = bundle.GetStringFromName("pageInfo_NoEncryption");
+    hdr = pkiBundle.getString("pageInfo_NoEncryption");
     if (info.hostName != null)
-      msg1 = bundle.formatStringFromName("pageInfo_Privacy_None1", [ info.hostName ], 1);
+      msg1 = pkiBundle.getFormattedString("pageInfo_Privacy_None1", [info.hostName]);
     else
-      msg1 = bundle.GetStringFromName("pageInfo_Privacy_None3");
-    msg2 = bundle.GetStringFromName("pageInfo_Privacy_None2");
+      msg1 = pkiBundle.getString("pageInfo_Privacy_None3");
+    msg2 = pkiBundle.getString("pageInfo_Privacy_None2");
   }
   setText("security-technical-shortform", hdr);
   setText("security-technical-longform1", msg1);
