@@ -1,4 +1,4 @@
-//@line 39 "/builds/tinderbox/Fx-Trunk/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/base/content/web-panels.js"
+//@line 39 "/builds/slave/mozilla-1.9.1-linux-nightly/build/browser/base/content/web-panels.js"
 
 const NS_ERROR_MODULE_NETWORK = 2152398848;
 const NS_NET_STATUS_READ_FROM = NS_ERROR_MODULE_NETWORK + 8;
@@ -78,7 +78,6 @@ function load()
                              null, null);
     }
 
-    gNavigatorBundle = document.getElementById("bundle_browser");
     gLoadFired = true;
 }
 
