@@ -203,6 +203,10 @@ function commonDialogOnLoad()
                 .playSystemSound(sound);
     }
   } catch (e) { }
+
+  var observerService = Components.classes["@mozilla.org/observer-service;1"]
+                                  .getService(Components.interfaces.nsIObserverService);
+  observerService.notifyObservers(window, "common-dialog-loaded", null);
 }
 
 var gDelayExpired = false;
